Documentation
¶
Overview ¶
URTator - Urban Terror server browser and game launcher, written in Go.
Copyright (c) 2016, Stanslav N. a.k.a pztrn (or p0z1tr0n) All rights reserved.
Licensed under Terms and Conditions of GNU General Public License version 3 or any higher. ToDo: put full text of license here.
URTator - Urban Terror server browser and game launcher, written in Go.
Copyright (c) 2016, Stanslav N. a.k.a pztrn (or p0z1tr0n) All rights reserved.
Licensed under Terms and Conditions of GNU General Public License version 3 or any higher. ToDo: put full text of license here.
URTator - Urban Terror server browser and game launcher, written in Go.
Copyright (c) 2016, Stanslav N. a.k.a pztrn (or p0z1tr0n) All rights reserved.
Licensed under Terms and Conditions of GNU General Public License version 3 or any higher. ToDo: put full text of license here.
URTator - Urban Terror server browser and game launcher, written in Go.
Copyright (c) 2016, Stanslav N. a.k.a pztrn (or p0z1tr0n) All rights reserved.
Licensed under Terms and Conditions of GNU General Public License version 3 or any higher. ToDo: put full text of license here.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Configuration ¶
type Profile ¶
type Profile struct {
// Profile name.
Name string `db:"name"`
// Game version.
Version string `db:"version"`
// Binary path.
Binary string `db:"binary"`
// Will we use second X session?
Second_x_session string `db:"second_x_session"`
// Additional game parameters we will pass.
Additional_params string `db:"additional_parameters"`
}
type Server ¶
type Server struct {
// Server's address
Ip string `db:"ip"`
// Server's port
Port string `db:"port"`
// Server's name
Name string `db:"name"`
// Current players count
Players string `db:"players"`
// Bots count
Bots string `db:"bots"`
// Maximum players
Maxplayers string `db:"maxplayers"`
// Ping
Ping string `db:"ping"`
// Gametype. See Urban Terror documentation on relationship.
Gamemode string `db:"gamemode"`
// Current map
Map string `db:"map"`
// Server's software version
Version string `db:"version"`
// Is server was favorited?
Favorite string `db:"favorite"`
// Server's password.
Password string `db:"password"`
// Profile to use with server.
ProfileToUse string `db:"profile_to_use"`
// Extended server's configuration.
ExtendedConfig string `db:"extended_config"`
// Players information.
PlayersInfo string `db:"players_info"`
// Is server private?
IsPrivate string `db:"is_private"`
}